RYA-405 More PR Updates
diff --git a/common/rya.api.function/src/main/java/org/apache/rya/api/function/filter/FilterEvaluator.java b/common/rya.api.function/src/main/java/org/apache/rya/api/function/filter/FilterEvaluator.java
index a70fc53..ca462f6 100644
--- a/common/rya.api.function/src/main/java/org/apache/rya/api/function/filter/FilterEvaluator.java
+++ b/common/rya.api.function/src/main/java/org/apache/rya/api/function/filter/FilterEvaluator.java
@@ -109,7 +109,7 @@
         } catch (final QueryEvaluationException e) {
             //False returned because for whatever reason, the ValueExpr could not be evaluated.
             //In the event that the ValueExpr is a FunctionCall, this Exception will be generated if
-            //the Function URI is a valid URI that was found in the FunctionRegistry, but the arguments
+            //the Function IRI is a valid IRI that was found in the FunctionRegistry, but the arguments
             //for that Function could not be parsed.
             log.error("Could not evaluate a Filter.", e);
             return false;
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/RdfCloudTripleStoreUtils.java b/common/rya.api/src/main/java/org/apache/rya/api/RdfCloudTripleStoreUtils.java
index 91cb74e..8a7c007 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/RdfCloudTripleStoreUtils.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/RdfCloudTripleStoreUtils.java
@@ -335,9 +335,9 @@
 //        if (s == null)
 //            return null;
 //
-//        for (String uri : s) {
-//            if (predicate.stringValue().equals(uri)) {
-//                return (Class<? extends TtlValueConverter>) RdfCloudTripleStoreUtils.class.getClassLoader().loadClass(conf.get(uri));
+//        for (String iri : s) {
+//            if (predicate.stringValue().equals(iri)) {
+//                return (Class<? extends TtlValueConverter>) RdfCloudTripleStoreUtils.class.getClassLoader().loadClass(conf.get(iri));
 //            }
 //        }
 //        return null;
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/domain/RyaTypeUtils.java b/common/rya.api/src/main/java/org/apache/rya/api/domain/RyaTypeUtils.java
index e7032e3..3136af3 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/domain/RyaTypeUtils.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/domain/RyaTypeUtils.java
@@ -181,7 +181,7 @@
 
     /**
      *
-     * Creates a URI {@link RyaType} object.
+     * Creates a IRI {@link RyaType} object.
      * @param value the {@link IRI} object.
      * @return the {@link RyaType} with the data type set to
      * {@link XMLSchema#ANYURI} and the data set to the specified {@code value}.
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/domain/VarNameUtils.java b/common/rya.api/src/main/java/org/apache/rya/api/domain/VarNameUtils.java
index 6f47e35..03c9e79 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/domain/VarNameUtils.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/domain/VarNameUtils.java
@@ -25,6 +25,8 @@
 import org.eclipse.rdf4j.query.algebra.Var;
 import org.eclipse.rdf4j.query.algebra.helpers.TupleExprs;
 
+import edu.umd.cs.findbugs.annotations.Nullable;
+
 /**
  * Utility methods and constants for RDF {@link Var} names.
  */
@@ -54,7 +56,7 @@
      * @param value the value to add the constant prefix to.
      * @return the value with the constant prefix attached before it.
      */
-    public static String prependConstant(final String value) {
+    public static @Nullable String prependConstant(@Nullable final String value) {
         if (value != null) {
             return CONSTANT_PREFIX + value;
         }
@@ -67,7 +69,7 @@
      * @return {@code true} if the name begins with the constant prefix.
      * {@code false} otherwise.
      */
-    public static boolean isConstant(final String name) {
+    public static boolean isConstant(@Nullable final String name) {
         if (name != null) {
             return name.startsWith(CONSTANT_PREFIX) || name.startsWith(LEGACY_CONSTANT_PREFIX);
         }
@@ -80,7 +82,7 @@
      * @return the string with the constant prefix removed. Otherwise returns
      * the original string.
      */
-    public static String removeConstant(final String name) {
+    public static @Nullable String removeConstant(@Nullable final String name) {
         if (isConstant(name)) {
             String removed = StringUtils.removeStart(name, CONSTANT_PREFIX);
             if (name.equals(removed)) {
@@ -96,7 +98,7 @@
      * @param value the value to add the anonymous prefix to.
      * @return the value with the anonymous prefix attached before it.
      */
-    public static String prependAnonymous(final String value) {
+    public static @Nullable String prependAnonymous(@Nullable final String value) {
         if (value != null) {
             return ANONYMOUS_PREFIX + value;
         }
@@ -109,7 +111,7 @@
      * @return {@code true} if the name begins with the anonymous prefix.
      * {@code false} otherwise.
      */
-    public static boolean isAnonymous(final String name) {
+    public static boolean isAnonymous(@Nullable final String name) {
         if (name != null) {
             return name.startsWith(ANONYMOUS_PREFIX) || name.startsWith(LEGACY_ANONYMOUS_PREFIX);
         }
@@ -122,7 +124,7 @@
      * @return the string with the anonymous prefix removed. Otherwise returns
      * the original string.
      */
-    public static String removeAnonymous(final String name) {
+    public static @Nullable String removeAnonymous(@Nullable final String name) {
         if (isAnonymous(name)) {
             String removed = StringUtils.removeStart(name, ANONYMOUS_PREFIX);
             if (name.equals(removed)) {
@@ -176,7 +178,7 @@
      * @param var the {@link Var}.
      * @return the simple constant var name.
      */
-    public static String createSimpleConstVarName(final Var var) {
+    public static @Nullable String createSimpleConstVarName(@Nullable final Var var) {
         String varName = null;
         if (var != null) {
             if (var.getValue() != null && isConstant(var.getName())) {
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/functions/DateTimeWithinPeriod.java b/common/rya.api/src/main/java/org/apache/rya/api/functions/DateTimeWithinPeriod.java
index 655425d..62720e6 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/functions/DateTimeWithinPeriod.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/functions/DateTimeWithinPeriod.java
@@ -37,7 +37,7 @@
  * This {@link Function} determines whether two {@link XMLSchema#DATETIME}s occur within a specified period of time of
  * one another. The method {@link Function#evaluate(ValueFactory, Value...)} expects four values, where the first two
  * values are the datetimes, the third value is an integer indicating the period, and the fourth value is a URI
- * indicating the time unit of the period. The URI must be of Type DurationDescription in the OWL-Time ontology (see
+ * indicating the time unit of the period. The IRI must be of Type DurationDescription in the OWL-Time ontology (see
  * <a href ="https://www.w3.org/TR/owl-time/">https://www.w3.org/TR/owl-time/</a>). Examples of valid time unit URIs can
  * be found in the class {@link OWLTime} and below
  * <ul>
@@ -60,7 +60,7 @@
     /**
      * Determines whether two datetimes occur within a specified period of time of one another. This method expects four
      * values, where the first two values are the datetimes, the third value is an integer indicating the period, and
-     * the fourth value is a URI indicating the time unit of the period. The URI must be of Type DurationDescription in
+     * the fourth value is an IRI indicating the time unit of the period. The IRI must be of Type DurationDescription in
      * the OWL-Time ontology (see <a href ="https://www.w3.org/TR/owl-time/">https://www.w3.org/TR/owl-time/</a>).
      * Examples of valid time unit URIs can be found in the class {@link OWLTime} and below
      * <ul>
@@ -118,7 +118,7 @@
      * Converts the period duration to milliseconds.
      *
      * @param duration - duration of temporal period
-     * @param unit - URI indicating the time unit (URI must be of type DurationDescription in the OWL-Time ontology
+     * @param unit - IRI indicating the time unit (URI must be of type DurationDescription in the OWL-Time ontology
      *            indicated by the namespace <http://www.w3.org/2006/time#>)
      * @return - duration in milliseconds
      */
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/resolver/RdfToRyaConversions.java b/common/rya.api/src/main/java/org/apache/rya/api/resolver/RdfToRyaConversions.java
index 6cd27b7..e89306e 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/resolver/RdfToRyaConversions.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/resolver/RdfToRyaConversions.java
@@ -60,7 +60,7 @@
 
     public static RyaType convertValue(Value value) {
         if (value == null) return null;
-        //assuming either uri or Literal here
+        //assuming either IRI or Literal here
         if(value instanceof Resource) {
             return convertResource((Resource) value);
         }
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/resolver/RyaToRdfConversions.java b/common/rya.api/src/main/java/org/apache/rya/api/resolver/RyaToRdfConversions.java
index 102db46..e9e1e46 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/resolver/RyaToRdfConversions.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/resolver/RyaToRdfConversions.java
@@ -55,7 +55,7 @@
     }
 
     public static Value convertValue(RyaType value) {
-        //assuming either uri or Literal here
+        //assuming either IRI or Literal here
         return (value instanceof RyaURI || value.getDataType().equals(XMLSchema.ANYURI)) ? convertURI(value) : convertLiteral(value);
     }
 
diff --git a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/OspWholeRowTriplePatternStrategyTest.java b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/OspWholeRowTriplePatternStrategyTest.java
index b9ef519..a3a467d 100644
--- a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/OspWholeRowTriplePatternStrategyTest.java
+++ b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/OspWholeRowTriplePatternStrategyTest.java
@@ -27,8 +27,9 @@
 //import org.apache.rya.api.resolver.triple.TripleRow;
 //import org.apache.accumulo.core.data.Key;
 //import org.apache.accumulo.core.data.Range;
+//import org.eclipse.rdf4j.model.ValueFactory;
+//import org.eclipse.rdf4j.model.impl.SimpleValueFactory;
 //import org.apache.hadoop.io.Text;
-//import org.eclipse.rdf4j.model.impl.URIImpl;
 //
 //import java.util.Map;
 //
@@ -37,14 +38,16 @@
 // * Time: 11:46 AM
 // */
 //public class OspWholeRowTriplePatternStrategyTest extends TestCase {
+//    private static final ValueFactory VF = SimpleValueFactory.getInstance();
+//
 //    RyaURI uri = new RyaURI("urn:test#1234");
 //    RyaURI uri2 = new RyaURI("urn:test#1235");
 //    RyaURIRange rangeURI = new RyaURIRange(uri, uri2);
 //    RyaURIRange rangeURI2 = new RyaURIRange(new RyaURI("urn:test#1235"), new RyaURI("urn:test#1236"));
 //
-//    RyaType customType1 = new RyaType(new URIImpl("urn:custom#type"), "1234");
-//    RyaType customType2 = new RyaType(new URIImpl("urn:custom#type"), "1235");
-//    RyaType customType3 = new RyaType(new URIImpl("urn:custom#type"), "1236");
+//    RyaType customType1 = new RyaType(VF.createIRI("urn:custom#type"), "1234");
+//    RyaType customType2 = new RyaType(VF.createIRI("urn:custom#type"), "1235");
+//    RyaType customType3 = new RyaType(VF.createIRI("urn:custom#type"), "1236");
 //    RyaTypeRange customTypeRange1 = new RyaTypeRange(customType1, customType2);
 //    RyaTypeRange customTypeRange2 = new RyaTypeRange(customType2, customType3);
 //
diff --git a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/PoWholeRowTriplePatternStrategyTest.java b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/PoWholeRowTriplePatternStrategyTest.java
index 12bfc1f..7060457 100644
--- a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/PoWholeRowTriplePatternStrategyTest.java
+++ b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/PoWholeRowTriplePatternStrategyTest.java
@@ -27,8 +27,9 @@
 //import org.apache.rya.api.resolver.triple.TripleRow;
 //import org.apache.accumulo.core.data.Key;
 //import org.apache.accumulo.core.data.Range;
+//import org.eclipse.rdf4j.model.ValueFactory;
+//import org.eclipse.rdf4j.model.impl.SimpleValueFactory;
 //import org.apache.hadoop.io.Text;
-//import org.eclipse.rdf4j.model.impl.URIImpl;
 //
 //import java.util.Map;
 //
@@ -37,6 +38,7 @@
 // * Time: 11:46 AM
 // */
 //public class PoWholeRowTriplePatternStrategyTest extends TestCase {
+//    private static final ValueFactory VF = SimpleValueFactory.getInstance();
 //
 //    RyaURI uri = new RyaURI("urn:test#1234");
 //    RyaURI uri2 = new RyaURI("urn:test#1235");
@@ -45,9 +47,9 @@
 //    PoWholeRowTriplePatternStrategy strategy = new PoWholeRowTriplePatternStrategy();
 //    RyaContext ryaContext = RyaContext.getInstance();
 //
-//    RyaType customType1 = new RyaType(new URIImpl("urn:custom#type"), "1234");
-//    RyaType customType2 = new RyaType(new URIImpl("urn:custom#type"), "1235");
-//    RyaType customType3 = new RyaType(new URIImpl("urn:custom#type"), "1236");
+//    RyaType customType1 = new RyaType(VF.createIRI("urn:custom#type"), "1234");
+//    RyaType customType2 = new RyaType(VF.createIRI("urn:custom#type"), "1235");
+//    RyaType customType3 = new RyaType(VF.createIRI("urn:custom#type"), "1236");
 //    RyaTypeRange customTypeRange1 = new RyaTypeRange(customType1, customType2);
 //    RyaTypeRange customTypeRange2 = new RyaTypeRange(customType2, customType3);
 //
diff --git a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/SpoWholeRowTriplePatternStrategyTest.java b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/SpoWholeRowTriplePatternStrategyTest.java
index 5e2ca7e..2c40053 100644
--- a/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/SpoWholeRowTriplePatternStrategyTest.java
+++ b/common/rya.api/src/test/java/org/apache/rya/api/query/strategy/wholerow/SpoWholeRowTriplePatternStrategyTest.java
@@ -27,8 +27,9 @@
 //import org.apache.rya.api.resolver.triple.TripleRow;
 //import org.apache.accumulo.core.data.Key;
 //import org.apache.accumulo.core.data.Range;
+//import org.eclipse.rdf4j.model.ValueFactory;
+//import org.eclipse.rdf4j.model.impl.SimpleValueFactory;
 //import org.apache.hadoop.io.Text;
-//import org.eclipse.rdf4j.model.impl.URIImpl;
 //
 //import java.util.Map;
 //
@@ -37,6 +38,7 @@
 // * Time: 7:47 AM
 // */
 //public class SpoWholeRowTriplePatternStrategyTest extends TestCase {
+//    private static final ValueFactory VF = SimpleValueFactory.getInstance();
 //
 //    RyaURI uri = new RyaURI("urn:test#1234");
 //    RyaURI uri2 = new RyaURI("urn:test#1235");
@@ -45,9 +47,9 @@
 //    SpoWholeRowTriplePatternStrategy strategy = new SpoWholeRowTriplePatternStrategy();
 //    RyaContext ryaContext = RyaContext.getInstance();
 //
-//    RyaType customType1 = new RyaType(new URIImpl("urn:custom#type"), "1234");
-//    RyaType customType2 = new RyaType(new URIImpl("urn:custom#type"), "1235");
-//    RyaType customType3 = new RyaType(new URIImpl("urn:custom#type"), "1236");
+//    RyaType customType1 = new RyaType(VF.createIRI("urn:custom#type"), "1234");
+//    RyaType customType2 = new RyaType(VF.createIRI("urn:custom#type"), "1235");
+//    RyaType customType3 = new RyaType(VF.createIRI("urn:custom#type"), "1236");
 //    RyaTypeRange customTypeRange1 = new RyaTypeRange(customType1, customType2);
 //    RyaTypeRange customTypeRange2 = new RyaTypeRange(customType2, customType3);
 //
diff --git a/dao/accumulo.rya/src/main/java/org/apache/rya/accumulo/AccumuloRdfQueryIterator.java b/dao/accumulo.rya/src/main/java/org/apache/rya/accumulo/AccumuloRdfQueryIterator.java
index e99cfe1..843298c 100644
--- a/dao/accumulo.rya/src/main/java/org/apache/rya/accumulo/AccumuloRdfQueryIterator.java
+++ b/dao/accumulo.rya/src/main/java/org/apache/rya/accumulo/AccumuloRdfQueryIterator.java
@@ -93,7 +93,7 @@
 //        open = true;
 //    }
 //
-//    public AccumuloRdfQueryIterator(Resource subject, URI predicate, Value object, Connector connector,
+//    public AccumuloRdfQueryIterator(Resource subject, IRI predicate, Value object, Connector connector,
 //                                    AccumuloRdfConfiguration conf, Resource[] contexts) throws RdfDAOException {
 //        this(Collections.<Entry<Statement, BindingSet>>singleton(new RdfCloudTripleStoreUtils.CustomEntry<Statement, BindingSet>(
 //                new NullableStatementImpl(subject, predicate, object, contexts),
@@ -114,7 +114,7 @@
 //            for (Entry<Statement, BindingSet> stmtbs : statements) {
 //                Statement stmt = stmtbs.getKey();
 //                Resource subject = stmt.getSubject();
-//                URI predicate = stmt.getPredicate();
+//                IRI predicate = stmt.getPredicate();
 //                Value object = stmt.getObject();
 //                context = stmt.getContext(); //TODO: assumes the same context for all statements
 //                logger.debug("Batch Scan, lookup subject[" + subject + "] predicate[" + predicate + "] object[" + object + "] combination");
diff --git a/dao/mongodb.rya/src/main/java/org/apache/rya/mongodb/dao/SimpleMongoDBStorageStrategy.java b/dao/mongodb.rya/src/main/java/org/apache/rya/mongodb/dao/SimpleMongoDBStorageStrategy.java
index a868e3d..b2490bc 100644
--- a/dao/mongodb.rya/src/main/java/org/apache/rya/mongodb/dao/SimpleMongoDBStorageStrategy.java
+++ b/dao/mongodb.rya/src/main/java/org/apache/rya/mongodb/dao/SimpleMongoDBStorageStrategy.java
@@ -65,7 +65,7 @@
 
     /**
      * Generate the hash that will be used to index and retrieve a given value.
-     * @param value  A value to be stored or accessed (e.g. a URI or literal).
+     * @param value  A value to be stored or accessed (e.g. a IRI or literal).
      * @return the hash associated with that value in MongoDB.
      */
     public static String hash(String value) {
diff --git a/extras/indexing/src/main/java/org/apache/rya/indexing/FilterFunctionOptimizer.java b/extras/indexing/src/main/java/org/apache/rya/indexing/FilterFunctionOptimizer.java
index d5653a0..5ce6bfb 100644
--- a/extras/indexing/src/main/java/org/apache/rya/indexing/FilterFunctionOptimizer.java
+++ b/extras/indexing/src/main/java/org/apache/rya/indexing/FilterFunctionOptimizer.java
@@ -132,7 +132,7 @@
         for (final StatementPattern matchStatement: matchStatements.matchStatements) {
             final Var subject = matchStatement.getSubjectVar();
             if (subject.hasValue() && !(subject.getValue() instanceof Resource)) {
-                throw new IllegalArgumentException("Query error: Found " + subject.getValue() + ", expected an URI or BNode");
+                throw new IllegalArgumentException("Query error: Found " + subject.getValue() + ", expected an IRI or BNode");
             }
             Validate.isTrue(subject.hasValue() || subject.getName() != null);
             Validate.isTrue(!matchStatement.getObjectVar().hasValue() && matchStatement.getObjectVar().getName() != null);
diff --git a/extras/indexing/src/main/java/org/apache/rya/indexing/accumulo/AccumuloIndexingConfiguration.java b/extras/indexing/src/main/java/org/apache/rya/indexing/accumulo/AccumuloIndexingConfiguration.java
index 9e6e92b..e6deab7 100644
--- a/extras/indexing/src/main/java/org/apache/rya/indexing/accumulo/AccumuloIndexingConfiguration.java
+++ b/extras/indexing/src/main/java/org/apache/rya/indexing/accumulo/AccumuloIndexingConfiguration.java
@@ -255,7 +255,7 @@
 
     /**
      * Sets the predicates used for freetext indexing
-     * @param predicates - Array of predicate URI strings used for freetext indexing
+     * @param predicates - Array of predicate IRI strings used for freetext indexing
      */
     public void setAccumuloFreeTextPredicates(final String[] predicates) {
         Preconditions.checkNotNull(predicates, "Freetext predicates cannot be null.");
@@ -264,7 +264,7 @@
 
     /**
      * Gets the predicates used for freetext indexing
-     * @return Array of predicate URI strings used for freetext indexing
+     * @return Array of predicate IRI strings used for freetext indexing
      */
     public String[] getAccumuloFreeTextPredicates() {
         return getStrings(ConfigUtils.FREETEXT_PREDICATES_LIST);
@@ -272,7 +272,7 @@
 
     /**
      * Sets the predicates used for temporal indexing
-     * @param predicates - Array of predicate URI strings used for temporal indexing
+     * @param predicates - Array of predicate IRI strings used for temporal indexing
      */
     public void setAccumuloTemporalPredicates(final String[] predicates) {
         Preconditions.checkNotNull(predicates, "Freetext predicates cannot be null.");
@@ -281,7 +281,7 @@
 
     /**
      * Gets the predicates used for temporal indexing
-     * @return Array of predicate URI strings used for temporal indexing
+     * @return Array of predicate IRI strings used for temporal indexing
      */
     public String[] getAccumuloTemporalPredicates() {
         return getStrings(ConfigUtils.TEMPORAL_PREDICATES_LIST);
diff --git a/extras/indexing/src/main/java/org/apache/rya/indexing/entity/update/BaseEntityIndexer.java b/extras/indexing/src/main/java/org/apache/rya/indexing/entity/update/BaseEntityIndexer.java
index 52d6f4d..26247a6 100644
--- a/extras/indexing/src/main/java/org/apache/rya/indexing/entity/update/BaseEntityIndexer.java
+++ b/extras/indexing/src/main/java/org/apache/rya/indexing/entity/update/BaseEntityIndexer.java
@@ -66,7 +66,7 @@
     private static final Logger log = Logger.getLogger(BaseEntityIndexer.class);
 
     /**
-     * When this URI is the Predicate of a Statement, it indicates a {@link Type} for an {@link Entity}.
+     * When this IRI is the Predicate of a Statement, it indicates a {@link Type} for an {@link Entity}.
      */
     private static final RyaURI TYPE_URI = new RyaURI( RDF.TYPE.toString() );
 
diff --git a/extras/indexing/src/main/java/org/apache/rya/indexing/mongodb/MongoIndexingConfiguration.java b/extras/indexing/src/main/java/org/apache/rya/indexing/mongodb/MongoIndexingConfiguration.java
index 3ccdc9a..25bb0b8 100644
--- a/extras/indexing/src/main/java/org/apache/rya/indexing/mongodb/MongoIndexingConfiguration.java
+++ b/extras/indexing/src/main/java/org/apache/rya/indexing/mongodb/MongoIndexingConfiguration.java
@@ -166,7 +166,7 @@
 
     /**
      * Sets the predicates that the {@link MongoFreeTextIndexer} uses for indexing
-     * @param predicates - predicate URI used for freetext indexing
+     * @param predicates - predicate IRI used for freetext indexing
      */
     public void setMongoFreeTextPredicates(final String[] predicates) {
         Preconditions.checkNotNull(predicates, "Freetext predicates cannot be null.");
@@ -174,7 +174,7 @@
     }
 
     /**
-     * @return Array of predicate URI Strings used for freetext indexing
+     * @return Array of predicate IRI Strings used for freetext indexing
      */
     public String[] getMongoFreeTextPredicates() {
         return getStrings(ConfigUtils.FREETEXT_PREDICATES_LIST);
@@ -182,7 +182,7 @@
 
     /**
      * Sets the predicates that the {@link MongoTemporalIndexer} uses for indexing
-     * @param predicates - predicate URI used for temporal indexing
+     * @param predicates - predicate IRI used for temporal indexing
      */
     public void setMongoTemporalPredicates(final String[] predicates) {
         Preconditions.checkNotNull(predicates, "Freetext predicates cannot be null.");
@@ -191,7 +191,7 @@
 
     /**
      * Gets the predicates that the {@link MongoTemporalIndexer} uses for indexing
-     * @return Array of predicate URI Strings used for temporal indexing
+     * @return Array of predicate IRI Strings used for temporal indexing
      */
     public String[] getMongoTemporalPredicates() {
         return getStrings(ConfigUtils.TEMPORAL_PREDICATES_LIST);
diff --git a/extras/indexing/src/main/java/org/apache/rya/indexing/smarturi/SmartUriAdapter.java b/extras/indexing/src/main/java/org/apache/rya/indexing/smarturi/SmartUriAdapter.java
index b6fe556..d46d310 100644
--- a/extras/indexing/src/main/java/org/apache/rya/indexing/smarturi/SmartUriAdapter.java
+++ b/extras/indexing/src/main/java/org/apache/rya/indexing/smarturi/SmartUriAdapter.java
@@ -295,8 +295,8 @@
                 if (StringUtils.isNotBlank(typeShortName)) {
                     formattedKey = addTypePrefixToUri(formattedKey, typeShortName);
                 }
-                final IRI uri = VF.createIRI(formattedKey);
-                objectMap.put(uri, value);
+                final IRI iri = VF.createIRI(formattedKey);
+                objectMap.put(iri, value);
             }
         }
 
@@ -341,7 +341,7 @@
 
         uriBuilder.setParameters(nameValuePairs);
 
-        IRI uri = null;
+        IRI iri = null;
         try {
             if (fragmentPosition > -1) {
                 final java.net.URI partialUri = uriBuilder.build();
@@ -349,26 +349,26 @@
                 final URIBuilder fragmentUriBuilder = new URIBuilder(new java.net.URI(prefix));
                 fragmentUriBuilder.setFragment(uriString);
                 final String fragmentUriString = fragmentUriBuilder.build().toString();
-                uri = VF.createIRI(fragmentUriString);
+                iri = VF.createIRI(fragmentUriString);
             } else {
                 final String uriString = uriBuilder.build().toString();
-                uri = VF.createIRI(uriString);
+                iri = VF.createIRI(uriString);
             }
         } catch (final URISyntaxException e) {
             throw new SmartUriException("Smart URI could not serialize the property map.", e);
         }
 
-        return uri;
+        return iri;
     }
 
     /**
-     * Deserializes a URI into a map of URI's to values.
-     * @param uri the {@link IRI}.
+     * Deserializes an IRI into a map of URI's to values.
+     * @param iri the {@link IRI}.
      * @return the {@link Map} of {@link IRI}s to {@link Value}s.
      * @throws SmartUriException
      */
-    public static Map<IRI, Value> deserializeUri(final IRI uri) throws SmartUriException {
-        final String uriString = uri.stringValue();
+    public static Map<IRI, Value> deserializeUri(final IRI iri) throws SmartUriException {
+        final String uriString = iri.stringValue();
         final int fragmentPosition = uriString.indexOf("#");
         String prefix = uriString.substring(0, fragmentPosition + 1);
         if (fragmentPosition == -1) {
@@ -389,7 +389,7 @@
             throw new SmartUriException("Unable to deserialize Smart URI", e);
         }
         final Map<IRI, Value> map = new HashMap<>();
-        final RyaURI subject = findSubject(uri.stringValue());
+        final RyaURI subject = findSubject(iri.stringValue());
 
         final List<NameValuePair> parameters = uriBuilder.getQueryParams();
         Map<RyaURI, String> entityTypeMap = new LinkedHashMap<>();
@@ -580,10 +580,10 @@
         for (final Entry<RyaURI, ImmutableMap<RyaURI, Property>> entry : entity.getProperties().entrySet()) {
             for (final Entry<RyaURI, Property> property : entry.getValue().entrySet()) {
                 final RyaURI propertyKey = property.getKey();
-                final IRI uri = VF.createIRI(propertyKey.getData());
+                final IRI iri = VF.createIRI(propertyKey.getData());
                 final Property propertyValue = property.getValue();
                 final Value value = RyaToRdfConversions.convertValue(propertyValue.getValue());
-                map.put(uri, value);
+                map.put(iri, value);
             }
         }
         return map;
@@ -598,10 +598,10 @@
     public static Set<Property> mapToProperties(final Map<IRI, Value> map) {
         final Set<Property> properties = new LinkedHashSet<>();
         for (final Entry<IRI, Value> entry : map.entrySet()) {
-            final IRI uri = entry.getKey();
+            final IRI iri = entry.getKey();
             final Value value = entry.getValue();
 
-            final RyaURI ryaUri = new RyaURI(uri.stringValue());
+            final RyaURI ryaUri = new RyaURI(iri.stringValue());
             final RyaType ryaType = RdfToRyaConversions.convertValue(value);
 
             final Property property = new Property(ryaUri, ryaType);
@@ -613,9 +613,9 @@
     public static Map<IRI, Value> propertiesToMap(final Set<Property> properties) {
         final Map<IRI, Value> map = new LinkedHashMap<>();
         for (final Property property : properties) {
-            final IRI uri = VF.createIRI(property.getName().getData());
+            final IRI iri = VF.createIRI(property.getName().getData());
             final Value value = RyaToRdfConversions.convertValue(property.getValue());
-            map.put(uri, value);
+            map.put(iri, value);
         }
         return map;
     }
diff --git a/extras/rya.forwardchain/src/main/java/org/apache/rya/forwardchain/rule/SpinConstructRule.java b/extras/rya.forwardchain/src/main/java/org/apache/rya/forwardchain/rule/SpinConstructRule.java
index 114d88e..c505e2a 100644
--- a/extras/rya.forwardchain/src/main/java/org/apache/rya/forwardchain/rule/SpinConstructRule.java
+++ b/extras/rya.forwardchain/src/main/java/org/apache/rya/forwardchain/rule/SpinConstructRule.java
@@ -80,7 +80,7 @@
     private Set<StatementPattern> consequentStatementPatterns = null;
 
     /**
-     * Instantiate a SPIN construct rule given its associated type, URI or bnode
+     * Instantiate a SPIN construct rule given its associated type, IRI or bnode
      * identifier, and construct query tree. Modifies the query tree to
      * incorporate the fact that ?this must belong to the associated type, and
      * traverses the modified tree to find antecedent and consequent triple
@@ -116,7 +116,7 @@
     }
 
     /**
-     * Get the URI or bnode associated with this rule in the data.
+     * Get the IRI or bnode associated with this rule in the data.
      * @return The rule's identifier.
      */
     public Resource getId() {
diff --git a/extras/rya.geoindexing/geo.common/src/main/java/org/apache/rya/indexing/GeoEnabledFilterFunctionOptimizer.java b/extras/rya.geoindexing/geo.common/src/main/java/org/apache/rya/indexing/GeoEnabledFilterFunctionOptimizer.java
index bd82c21..a82656a 100644
--- a/extras/rya.geoindexing/geo.common/src/main/java/org/apache/rya/indexing/GeoEnabledFilterFunctionOptimizer.java
+++ b/extras/rya.geoindexing/geo.common/src/main/java/org/apache/rya/indexing/GeoEnabledFilterFunctionOptimizer.java
@@ -159,7 +159,7 @@
         for (final StatementPattern matchStatement: matchStatements.matchStatements) {
             final Var subject = matchStatement.getSubjectVar();
             if (subject.hasValue() && !(subject.getValue() instanceof Resource)) {
-                throw new IllegalArgumentException("Query error: Found " + subject.getValue() + ", expected an URI or BNode");
+                throw new IllegalArgumentException("Query error: Found " + subject.getValue() + ", expected an IRI or BNode");
             }
             Validate.isTrue(subject.hasValue() || subject.getName() != null);
             Validate.isTrue(!matchStatement.getObjectVar().hasValue() && matchStatement.getObjectVar().getName() != null);
diff --git a/extras/rya.indexing.pcj/src/main/java/org/apache/rya/indexing/pcj/storage/accumulo/BindingSetStringConverter.java b/extras/rya.indexing.pcj/src/main/java/org/apache/rya/indexing/pcj/storage/accumulo/BindingSetStringConverter.java
index 45a1f61..4cf54dc 100644
--- a/extras/rya.indexing.pcj/src/main/java/org/apache/rya/indexing/pcj/storage/accumulo/BindingSetStringConverter.java
+++ b/extras/rya.indexing.pcj/src/main/java/org/apache/rya/indexing/pcj/storage/accumulo/BindingSetStringConverter.java
@@ -122,7 +122,7 @@
         final String dataString = valueAndType[0];
         final String typeString = valueAndType[1];
 
-        // Convert the String Type into a URI that describes the type.
+        // Convert the String Type into a IRI that describes the type.
         final IRI typeURI = VF.createIRI(typeString);
 
         // Convert the String Value into a Value.
diff --git a/extras/rya.pcj.fluo/pcj.fluo.api/src/main/java/org/apache/rya/indexing/pcj/fluo/api/CreatePeriodicQuery.java b/extras/rya.pcj.fluo/pcj.fluo.api/src/main/java/org/apache/rya/indexing/pcj/fluo/api/CreatePeriodicQuery.java
index 0e7c7cf..85db252 100644
--- a/extras/rya.pcj.fluo/pcj.fluo.api/src/main/java/org/apache/rya/indexing/pcj/fluo/api/CreatePeriodicQuery.java
+++ b/extras/rya.pcj.fluo/pcj.fluo.api/src/main/java/org/apache/rya/indexing/pcj/fluo/api/CreatePeriodicQuery.java
@@ -43,7 +43,7 @@
  * requesting periodic updates about events that occurred within a given
  * window of time of this instant. This is also known as a rolling window
  * query.  Period Queries can be expressed using SPARQL by including the
- * {@link Function} indicated by the URI {@link PeriodicQueryUtil#PeriodicQueryURI}
+ * {@link Function} indicated by the IRI {@link PeriodicQueryUtil#PeriodicQueryURI}
  * in the query.  The user must provide this Function with the following arguments:
  * the temporal variable in the query that will be filtered on, the window of time
  * that events must occur within, the period at which the user wants to receive updates,
diff --git a/extras/rya.pcj.fluo/pcj.fluo.app/src/main/java/org/apache/rya/indexing/pcj/fluo/app/util/PeriodicQueryUtil.java b/extras/rya.pcj.fluo/pcj.fluo.app/src/main/java/org/apache/rya/indexing/pcj/fluo/app/util/PeriodicQueryUtil.java
index 17fedf7..c1bdef2 100644
--- a/extras/rya.pcj.fluo/pcj.fluo.app/src/main/java/org/apache/rya/indexing/pcj/fluo/app/util/PeriodicQueryUtil.java
+++ b/extras/rya.pcj.fluo/pcj.fluo.app/src/main/java/org/apache/rya/indexing/pcj/fluo/app/util/PeriodicQueryUtil.java
@@ -55,7 +55,7 @@
 import com.google.common.base.Preconditions;
 
 /**
- * Utility class for creating and executing Perioid Queries.
+ * Utility class for creating and executing Periodic Queries.
  *
  */
 public class PeriodicQueryUtil {
@@ -70,7 +70,7 @@
     /**
      * Returns a PeriodicQueryNode for all {@link FunctionCall}s that represent PeriodicQueryNodes, otherwise
      * an empty Optional is returned.
-     * @param functionCall - FunctionCall taken from a {@lin TupleExpr}
+     * @param functionCall - FunctionCall taken from a {@link TupleExpr}
      * @param arg - TupleExpr that will be the argument of the PeriodicQueryNode if it is created
      * @return - Optional containing a PeriodicQueryNode if FunctionCall represents PeriodicQueryNode and empty Optional otherwise
      * @throws Exception
diff --git a/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/BatchIT.java b/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/BatchIT.java
index 555e002..8ebc9fc 100644
--- a/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/BatchIT.java
+++ b/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/BatchIT.java
@@ -145,8 +145,8 @@
             VisibilityBindingSet vBs = new VisibilityBindingSet(bs);
 
             //create sharded span for deletion
-            IRI uri = VF.createIRI("urn:subject_1");
-            Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(rightSp, uri);
+            IRI iri = VF.createIRI("urn:subject_1");
+            Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(rightSp, iri);
             Span span = Span.prefix(prefixBytes);
 
             // Stream the data into Fluo.
@@ -194,8 +194,8 @@
             bs.addBinding("object1", VF.createIRI("urn:object_0"));
             VisibilityBindingSet vBs = new VisibilityBindingSet(bs);
 
-            IRI uri = VF.createIRI("urn:subject_1");
-            Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(rightSp, uri);
+            IRI iri = VF.createIRI("urn:subject_1");
+            Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(rightSp, iri);
             Span span = Span.prefix(prefixBytes);
 
             // Stream the data into Fluo.
@@ -368,8 +368,8 @@
             for (int i = 0; i < ids.size(); i++) {
                 String id = ids.get(i);
                 String bsPrefix = prefixes.get(i);
-                IRI uri = VF.createIRI(bsPrefix);
-                Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(id, uri);
+                IRI iri = VF.createIRI(bsPrefix);
+                Bytes prefixBytes = BindingHashShardingFunction.getShardedScanPrefix(id, iri);
                 NodeType type = NodeType.fromNodeId(id).get();
                 Column bsCol = type.getResultColumn();
                 SpanBatchDeleteInformation.Builder builder = SpanBatchDeleteInformation.builder().setBatchSize(batchSize)
diff --git a/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/StreamingTestIT.java b/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/StreamingTestIT.java
index 776b69f..b387e10 100644
--- a/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/StreamingTestIT.java
+++ b/extras/rya.pcj.fluo/pcj.fluo.integration/src/test/java/org/apache/rya/indexing/pcj/fluo/integration/StreamingTestIT.java
@@ -83,10 +83,10 @@
 	private void addRandomQueryStatementPairs(final int numPairs) throws Exception {
 		final Set<Statement> statementPairs = new HashSet<>();
 		for (int i = 0; i < numPairs; i++) {
-			final String uri = "http://uuid_" + UUID.randomUUID().toString();
-			final Statement statement1 = VF.createStatement(VF.createIRI(uri), VF.createIRI("http://pred1"),
+			final String iri = "http://uuid_" + UUID.randomUUID().toString();
+			final Statement statement1 = VF.createStatement(VF.createIRI(iri), VF.createIRI("http://pred1"),
 					VF.createLiteral("number_" + (i + 1)));
-			final Statement statement2 = VF.createStatement(VF.createIRI(uri), VF.createIRI("http://pred2"), VF.createLiteral("literal"));
+			final Statement statement2 = VF.createStatement(VF.createIRI(iri), VF.createIRI("http://pred2"), VF.createLiteral("literal"));
 			statementPairs.add(statement1);
 			statementPairs.add(statement2);
 		}
diff --git a/extras/rya.reasoning/README.md b/extras/rya.reasoning/README.md
index 812542d..6401285 100644
--- a/extras/rya.reasoning/README.md
+++ b/extras/rya.reasoning/README.md
@@ -333,7 +333,7 @@
 
 Reasoning is distributed according to URI: Mappers read in triples from Accumulo
 and from previous iterations, and partition triples according to their subject
-and object. Reducers perform reasoning around one URI at a time, receiving as
+and object. Reducers perform reasoning around one IRI at a time, receiving as
 input only triples involving that URI. This enables us to use MapReduce, but
 requires making several passes through the data in cases where information
 needs to be propagated several steps through the graph (for example, with
@@ -710,8 +710,8 @@
 
 - An **OwlProperty** or **OwlClass** represents a property or a class, respectively.
     Each object holds a reference to the RDF entity that identifies it (using to
-    the RDF4J api): a URI for each OwlProperty, and a Resource for each class
-    (because a class is more general; it can be a URI or a bnode).
+    the RDF4J api): an IRI for each OwlProperty, and a Resource for each class
+    (because a class is more general; it can be an IRI or a bnode).
 
     Both maintain connections to other schema constructs, according to the
     relevant schema connections that can be made for each type. In general,
diff --git a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/Schema.java b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/Schema.java
index fabc074..0453a30 100644
--- a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/Schema.java
+++ b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/Schema.java
@@ -89,11 +89,11 @@
     };
 
     static {
-        for (IRI uri : schemaPredicateURIs) {
-            schemaPredicates.add(uri);
+        for (IRI iri : schemaPredicateURIs) {
+            schemaPredicates.add(iri);
         }
-        for (Resource uri : schemaTypeURIs) {
-            schemaTypes.add(uri);
+        for (Resource iri : schemaTypeURIs) {
+            schemaTypes.add(iri);
         }
     }
 
diff --git a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/TypeReasoner.java b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/TypeReasoner.java
index 8ccc774..67f9164 100644
--- a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/TypeReasoner.java
+++ b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/TypeReasoner.java
@@ -199,11 +199,11 @@
     public String getDiagnostics() {
         int total = 0;
         int incTotal = 0;
-        for (Resource uri : possibleInferences.keySet()) {
-            total += possibleInferences.get(uri).size();
+        for (Resource iri : possibleInferences.keySet()) {
+            total += possibleInferences.get(iri).size();
         }
-        for (Resource uri : possibleInconsistencies.keySet()) {
-            incTotal += possibleInconsistencies.get(uri).size();
+        for (Resource iri : possibleInconsistencies.keySet()) {
+            incTotal += possibleInconsistencies.get(iri).size();
         }
         StringBuilder sb = new StringBuilder();
         sb.append(knownTypes.size()).append(" total types known\n");
diff --git a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ConformanceTest.java b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ConformanceTest.java
index 34c8c44..87f1c8b 100644
--- a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ConformanceTest.java
+++ b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ConformanceTest.java
@@ -378,15 +378,15 @@
         final TupleQueryResult queryResult = query.evaluate();
         while (queryResult.hasNext()) {
             final BindingSet bindings = queryResult.next();
-            final Value uri = bindings.getValue("test");
-            if (testURIs.contains(uri)) {
+            final Value iri = bindings.getValue("test");
+            if (testURIs.contains(iri)) {
                 OwlTest test;
-                if (tests.containsKey(uri)) {
-                    test = tests.get(uri);
+                if (tests.containsKey(iri)) {
+                    test = tests.get(iri);
                 }
                 else {
                     test = new OwlTest();
-                    test.uri = uri;
+                    test.uri = iri;
                     test.name = bindings.getValue("name").stringValue();
                     test.description = bindings.getValue("description").stringValue();
                     test.premise = bindings.getValue("graph").stringValue();
@@ -396,7 +396,7 @@
                     if (bindings.hasBinding("nonentailed")) {
                         test.compareTo = bindings.getValue("nonentailed").stringValue();
                     }
-                    tests.put(uri, test);
+                    tests.put(iri, test);
                 }
                 test.types.add(bindings.getValue("testType").stringValue());
             }
diff --git a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ResourceWritable.java b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ResourceWritable.java
index 06f0d20..4305adb 100644
--- a/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ResourceWritable.java
+++ b/extras/rya.reasoning/src/main/java/org/apache/rya/reasoning/mr/ResourceWritable.java
@@ -29,7 +29,7 @@
 import org.eclipse.rdf4j.model.impl.SimpleValueFactory;
 
 /**
- * Allows us to use a URI or bnode for a key.
+ * Allows us to use an IRI or bnode for a key.
  */
 public class ResourceWritable implements WritableComparable<ResourceWritable> {
     private Resource val;
diff --git a/extras/vagrantExample/src/main/vagrant/Vagrantfile b/extras/vagrantExample/src/main/vagrant/Vagrantfile
index 2330bd9..bfa882f 100644
--- a/extras/vagrantExample/src/main/vagrant/Vagrantfile
+++ b/extras/vagrantExample/src/main/vagrant/Vagrantfile
@@ -314,7 +314,7 @@
 	ryaIndexing=rya.indexing.example-${RYA_EXAMPLE_VERSION}-distribution
 	if [[ ! -s ${ryaIndexing}.zip ]] ; then
 		# Eventually it'll be on maven...
-		echo "Downloading ${ryaIndexing} quietly, this will take some minutes with no output..."
+		echo "Downloading ${ryaIndexing}.zip quietly, this will take some minutes with no output..."
 		download --output ${ryaIndexing}.zip ${mavenRepoUrl}org/apache/rya/rya.indexing.example/${RYA_EXAMPLE_VERSION}/${ryaIndexing}.zip?raw=1  || exit 112
 	fi
 	sudo mkdir --parents ${ryaIndexing}
@@ -340,8 +340,8 @@
 	echo "Downloading and installing new templates for RDF4J WorkBench"
 	ryaVagrant=rya.vagrant.example-${RYA_EXAMPLE_VERSION}
 	if [[ ! -s ${ryaVagrant}.jar ]] ; then
-		echo "Downloading ${ryaVagrant}"
-		download --output ${ryaVagrant}.jar  ${mavenRepoUrl}org/apache/rya/rya.vagrant.example/${RYA_EXAMPLE_VERSION}/${ryaVagrant}.jar?raw=1 || exit 120
+		echo "Downloading ${ryaVagrant}.jar"
+		download --output ${ryaVagrant}.jar ${mavenRepoUrl}org/apache/rya/rya.vagrant.example/${RYA_EXAMPLE_VERSION}/${ryaVagrant}.jar?raw=1 || exit 120
 	fi
 	sudo mkdir --parents ${ryaVagrant}
 	sudo unzip -q -o ${ryaVagrant}.jar -d ${ryaVagrant}
@@ -352,7 +352,7 @@
 	ryaWar=web.rya-${RYA_EXAMPLE_VERSION}.war
 	if [[ ! -s ${ryaWar} ]] ; then
 		echo "Downloading ${ryaWar}"
-		download ${mavenRepoUrl}org/apache/rya/web.rya/${RYA_EXAMPLE_VERSION}/${ryaWar}.jar?raw=1 --output ${ryaWar} || exit 121
+		download ${mavenRepoUrl}org/apache/rya/web.rya/${RYA_EXAMPLE_VERSION}/${ryaWar}?raw=1 --output ${ryaWar} || exit 121
 	fi
 	sudo cp ${ryaWar} /var/lib/tomcat7/webapps/web.rya.war
 	# Wait for the war to deploy
diff --git a/mapreduce/src/main/java/org/apache/rya/accumulo/mr/tools/Upgrade322Tool.java b/mapreduce/src/main/java/org/apache/rya/accumulo/mr/tools/Upgrade322Tool.java
index e271e27..adc2de2 100644
--- a/mapreduce/src/main/java/org/apache/rya/accumulo/mr/tools/Upgrade322Tool.java
+++ b/mapreduce/src/main/java/org/apache/rya/accumulo/mr/tools/Upgrade322Tool.java
@@ -61,7 +61,7 @@
         setupAccumuloInput(job);
         AccumuloInputFormat.setInputTableName(job, MRUtils.getTablePrefix(conf) + TBL_OSP_SUFFIX);
 
-        //we do not need to change any row that is a string, custom, or uri type
+        //we do not need to change any row that is a string, custom, or iri type
         IteratorSetting regex = new IteratorSetting(30, "regex",
                                                     RegExFilter.class);
         RegExFilter.setRegexs(regex, "\\w*" + TYPE_DELIM + "[\u0003|\u0008|\u0002]", null, null, null, false);
diff --git a/sail/src/main/java/org/apache/rya/rdftriplestore/inference/InferenceEngine.java b/sail/src/main/java/org/apache/rya/rdftriplestore/inference/InferenceEngine.java
index 8d6feb6..ada151a 100644
--- a/sail/src/main/java/org/apache/rya/rdftriplestore/inference/InferenceEngine.java
+++ b/sail/src/main/java/org/apache/rya/rdftriplestore/inference/InferenceEngine.java
@@ -1223,8 +1223,8 @@
 
     /**
      * Return whether a given property is known to be reflexive.
-     * @param prop A URI
-     * @return True if the given URI corresponds to an owl:ReflexiveProperty
+     * @param prop A IRI
+     * @return True if the given IRI corresponds to an owl:ReflexiveProperty
      */
     public boolean isReflexiveProperty(final IRI prop) {
         return (reflexivePropertySet != null) && reflexivePropertySet.contains(prop);
diff --git a/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreConnectionTest.java b/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreConnectionTest.java
index d40972c..5eab6c4 100644
--- a/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreConnectionTest.java
+++ b/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreConnectionTest.java
@@ -126,14 +126,14 @@
 
 //    public void testAddAuth() throws Exception {
 //        RepositoryConnection conn = repository.getConnection();
-//        URI cpu = vf.createIRI(litdupsNS, "cpu");
-//        URI loadPerc = vf.createIRI(litdupsNS, "loadPerc");
-//        URI uri1 = vf.createIRI(litdupsNS, "uri1");
-//        URI uri2 = vf.createIRI(litdupsNS, "uri2");
-//        URI uri3 = vf.createIRI(litdupsNS, "uri3");
-//        URI auth1 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "1");
-//        URI auth2 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "2");
-//        URI auth3 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "3");
+//        IRI cpu = vf.createIRI(litdupsNS, "cpu");
+//        IRI loadPerc = vf.createIRI(litdupsNS, "loadPerc");
+//        IRI uri1 = vf.createIRI(litdupsNS, "uri1");
+//        IRI uri2 = vf.createIRI(litdupsNS, "uri2");
+//        IRI uri3 = vf.createIRI(litdupsNS, "uri3");
+//        IRI auth1 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "1");
+//        IRI auth2 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "2");
+//        IRI auth3 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "3");
 //        conn.add(cpu, loadPerc, uri1, auth1, auth2, auth3);
 //        conn.add(cpu, loadPerc, uri2, auth2, auth3);
 //        conn.add(cpu, loadPerc, uri3, auth3);
@@ -975,7 +975,7 @@
 //    public void testNamedGraphLoadWInlineAuth() throws Exception {
 //        InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("namedgraphs.trig");
 //        assertNotNull(stream);
-//        URI auth1 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "1");
+//        IRI auth1 = vf.createIRI(RdfCloudTripleStoreConstants.AUTH_NAMESPACE, "1");
 //        RepositoryConnection conn = repository.getConnection();
 //        conn.add(stream, "", RDFFormat.TRIG, auth1);
 //        conn.commit();
diff --git a/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreUtilsTest.java b/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreUtilsTest.java
index 63d0ade..f2d3f76 100644
--- a/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreUtilsTest.java
+++ b/sail/src/test/java/org/apache/rya/RdfCloudTripleStoreUtilsTest.java
@@ -38,8 +38,8 @@
 //
 //	public void testWriteReadURI() throws Exception {
 //		final ValueFactory vf = SimpleValueFactory.getInstance();
-//		IRI uri = vf.createIRI("http://www.example.org/test/rel");
-//		byte[] value = writeValue(uri);
+//		IRI iri = vf.createIRI("http://www.example.org/test/rel");
+//		byte[] value = writeValue(iri);
 //
 //		Value readValue = readValue(ByteStreams
 //				.newDataInput(value), vf);
diff --git a/common/rya.api/src/main/java/org/apache/rya/api/functions/OWLTime.java b/common/rya.api/src/main/java/org/apache/rya/api/functions/OWLTime.java
index 48649d1..9e19e62 100644
--- a/common/rya.api/src/main/java/org/apache/rya/api/functions/OWLTime.java
+++ b/common/rya.api/src/main/java/org/apache/rya/api/functions/OWLTime.java
@@ -74,38 +74,38 @@
     }
 
     /**
      * Verifies whether URI is a valid OWL-Time URI that is supported by this class.
      * @param durationURI - OWLTime URI indicating the time unit (not null)
      * @return - {@code true} if this URI indicates a supported OWLTime time unit
      */
-    public static boolean isValidDurationType(IRI durationURI) {
-        checkNotNull(durationURI);
-        return DURATION_MAP.containsKey(durationURI);
+    public static boolean isValidDurationType(IRI durationIRI) {
+        checkNotNull(durationIRI);
+        return DURATION_MAP.containsKey(durationIRI);
     }
 
     /**
      * Returns the duration in milliseconds
      *
-     * @param duration - amount of time in the units indicated by the provided {@link OWLTime} URI
-     * @param uri - OWLTime URI indicating the time unit of duration (not null)
+     * @param duration - amount of time in the units indicated by the provided {@link OWLTime} IRI
+     * @param iri - OWLTime IRI indicating the time unit of duration (not null)
      * @return - the amount of time in milliseconds
      * @throws IllegalArgumentException if provided {@link IRI} is not a valid, supported OWL-Time time unit.
      */
-    public static long getMillis(int duration, IRI uri) throws IllegalArgumentException {
-        Optional<ChronoUnit> unit = getChronoUnitFromURI(uri);
+    public static long getMillis(int duration, IRI iri) throws IllegalArgumentException {
+        Optional<ChronoUnit> unit = getChronoUnitFromURI(iri);
         checkArgument(unit.isPresent(),
-                String.format("URI %s does not indicate a valid OWLTime time unit.  URI must of be of type %s, %s, %s, %s, or %s .", uri,
+                String.format("IRI %s does not indicate a valid OWLTime time unit.  IRI must of be of type %s, %s, %s, %s, or %s .", iri,
                         SECONDS_URI, MINUTES_URI, HOURS_URI, DAYS_URI, WEEKS_URI));
         return duration * unit.get().getDuration().toMillis();
     }
 
     /**
-     * Converts the {@link OWLTime} URI time unit to a {@link ChronoUnit} time unit
+     * Converts the {@link OWLTime} IRI time unit to a {@link ChronoUnit} time unit
      *
      * @param durationURI - OWLTime time unit URI (not null)
      * @return - corresponding ChronoUnit time unit
      */
-    public static Optional<ChronoUnit> getChronoUnitFromURI(IRI durationURI) {
-        return Optional.ofNullable(DURATION_MAP.get(durationURI));
+    public static Optional<ChronoUnit> getChronoUnitFromURI(IRI durationIRI) {
+        return Optional.ofNullable(DURATION_MAP.get(durationIRI));
     }
 }
@@ -74,38 +74,38 @@
 
     /**
-     * Verifies whether URI is a valid OWL-Time URI that is supported by this class.
-     * @param durationURI - OWLTime URI indicating the time unit (not null)
-     * @return - {@code true} if this URI indicates a supported OWLTime time unit
+     * Verifies whether IRI is a valid OWL-Time IRI that is supported by this class.
+     * @param durationIRI - OWLTime IRI indicating the time unit (not null)
+     * @return - {@code true} if this IRI indicates a supported OWLTime time unit
      */
@@ -74,38 +74,38 @@
      *
-     * @param durationURI - OWLTime time unit URI (not null)
+     * @param durationIRI - OWLTime time unit IRI (not null)
      * @return - corresponding ChronoUnit time unit
      */